from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig

TIMING = {f'conf/{k}': v for k, v in {
    '525-ix-syntax/efm/00-filing/00-filing-efm-testcase.xml': 34.914,
    '525-ix-syntax/efm/01-format/01-format-efm-testcase.xml': 3.276,
    '525-ix-syntax/efm/02-transform/02-transform-efm-testcase.xml': 8.101,
    '525-ix-syntax/efm/04-nonnumeric/04-nonnumeric-efm-testcase.xml': 0.801,
    '525-ix-syntax/efm/09-footnote/09-footnote-efm-testcase.xml': 1.556,
    '525-ix-syntax/efm/10-header/10-header-efm-testcase.xml': 0.391,
    '525-ix-syntax/efm/11-hidden/11-hidden-efm-testcase.xml': 27.430,
    '525-ix-syntax/efm/12-references/12-references-efm-testcase.xml': 0.768,
    '525-ix-syntax/efm/16-redlining/16-redlining-testcase.xml': 0.838,
    '525-ix-syntax/efm/18-tuple/18-tuple-efm-testcase.xml': 0.404,
    '525-ix-syntax/efm/19-multiio/19-multiio-efm-testcase.xml': 16.441,
    '525-ix-syntax/efm/20-fraction/20-fraction-efm-testcase.xml': 0.407,
    '525-ix-syntax/efm/21-duplicates/21-duplicates-efm-testcase.xml': 3.103,
    '525-ix-syntax/efm/22-forms/22-forms-efm-testcase.xml': 25.878,
    '525-ix-syntax/efm/23-rr/23-rr-efm-testcase.xml': 6.564,
    '525-ix-syntax/ned/00-filing/00-filing-ned-testcase.xml': 2.443,
    '525-ix-syntax/ned/01-format/01-format-ned-testcase.xml': 1.201,
    '525-ix-syntax/ned/02-transform/02-transform-ned-testcase.xml': 3.203,
    '525-ix-syntax/ned/03-nonfraction/03-nonfraction-ned-testcase.xml': 11.850,
    '525-ix-syntax/ned/04-nonnumeric/04-nonnumeric-ned-testcase.xml': 5.596,
    '525-ix-syntax/ned/05-exclude/05-exclude-ned-testcase.xml': 1.106,
    '525-ix-syntax/ned/06-ids/06-ids-ned-testcase.xml': 3.997,
    '525-ix-syntax/ned/07-continuation/07-continuation-ned-testcase.xml': 6.159,
    '525-ix-syntax/ned/08-relationship/08-relationship-ned-testcase.xml': 2.850,
    '525-ix-syntax/ned/09-footnote/09-footnote-ned-testcase.xml': 5.299,
    '525-ix-syntax/ned/10-header/10-header-ned-testcase.xml': 1.402,
    '525-ix-syntax/ned/11-hidden/11-hidden-ned-testcase.xml': 2.319,
    '525-ix-syntax/ned/12-references/12-references-ned-testcase.xml': 5.790,
    '525-ix-syntax/ned/13-resources/13-resources-ned-testcase.xml': 1.578,
    '525-ix-syntax/ned/14-baseuri/14-baseuri-ned-testcase.xml': 0.823,
    '525-ix-syntax/ned/15-xmllang/15-xmllang-ned-testcase.xml': 1.969,
    '525-ix-syntax/ned/19-multiio/19-multiio-ned-testcase.xml': 2.280,
    '525-ix-syntax/ned/20-viewer-lang/20-viewer-testcase.xml': 0.462,
    '603-filing-syntax/603-03-filename-pattern/603-03-filename-pattern-testcase.xml': 0.845,
    '603-filing-syntax/603-04-no-html-character-entities/603-04-no-html-character-entities-testcase.xml': 0.699,
    '603-filing-syntax/603-05-only-xml-or-numeric-character-refs/603-05-only-xml-or-numeric-character-refs-testcase.xml': 2.109,
    '603-filing-syntax/603-06-uri-recognized/603-06-uri-recognized-testcase.xml': 2.554,
    '603-filing-syntax/603-11-no-xml-base/603-11-no-xml-base-testcase.xml': 3.418,
    '604-filing-semantics/604-03-xbrl-valid/604-03-xbrl-valid-testcase.xml': 10.906,
    '605-instance-syntax/605-01-entity-identifier-scheme/605-01-entity-identifier-scheme-testcase.xml': 0.722,
    '605-instance-syntax/605-02-entity-identifier-match-cik/605-02-entity-identifier-match-cik-testcase.xml': 1.056,
    '605-instance-syntax/605-03-entity-identifier-all-identical/605-03-entity-identifier-all-identical-testcase.xml': 0.655,
    '605-instance-syntax/605-04-no-scenario-elements/605-04-no-scenario-elements-testcase.xml': 1.125,
    '605-instance-syntax/605-07-no-duplicate-contexts/605-07-no-duplicate-contexts-testcase.xml': 1.159,
    '605-instance-syntax/605-08-no-unused-contexts/605-08-no-unused-contexts-testcase.xml': 0.397,
    '605-instance-syntax/605-09-start-and-end-dates-distinct/605-09-start-and-end-dates-distinct-testcase.xml': 4.154,
    '605-instance-syntax/605-11-no-duplicate-units/605-11-no-duplicate-units-testcase.xml': 1.287,
    '605-instance-syntax/605-12-no-duplicate-facts/605-12-no-duplicate-facts-testcase.xml': 6.421,
    '605-instance-syntax/605-13-english-default/605-13-english-default-testcase.xml': 1.604,
    '605-instance-syntax/605-14-foreign-content-needs-english/605-14-foreign-content-needs-english-testcase.xml': 2.246,
    '605-instance-syntax/605-15-text-blocks-xml-well-formed/605-15-text-blocks-xml-well-formed-testcase.xml': 4.428,
    '605-instance-syntax/605-16-html-limited/605-16-html-limited-testcase.xml': 9.806,
    '605-instance-syntax/605-17-decimals-not-precision/605-17-decimals-not-precision-testcase.xml': 0.874,
    '605-instance-syntax/605-19-required-context/605-19-required-context-testcase.xml': 1.801,
    '605-instance-syntax/605-20-required-document-elts/605-20-gen/605-20-gen-testcase.xml': 425.187,
    '605-instance-syntax/605-20-required-document-elts/605-20-man/605-20-man-testcase.xml': 1336.141,
    '605-instance-syntax/605-21-required-entity-elts/605-21-gen/605-21-gen-testcase.xml': 1384.742,
    '605-instance-syntax/605-21-required-entity-elts/605-21-man/605-21-man-testcase.xml': 1251.695,
    '605-instance-syntax/605-22-other-dei-elements-optional/605-22-other-dei-elements-optional-testcase.xml': 0.788,
    '605-instance-syntax/605-23-required-context-match-cik/605-23-required-context-match-cik-testcase.xml': 2.371,
    '605-instance-syntax/605-24-registrant-name-matches-dei/605-24-gen/605-24-gen-testcase.xml': 46.207,
    '605-instance-syntax/605-24-registrant-name-matches-dei/605-24-man/605-24-registrant-name-matches-dei-man-testcase.xml': 6.392,
    '605-instance-syntax/605-24-registrant-name-matches-dei/605-24-man1/605-24-man-testcase.xml': 59.221,
    '605-instance-syntax/605-25-no-domain-items-as-facts/605-25-no-domain-items-as-facts-testcase.xml': 2.831,
    '605-instance-syntax/605-26-common-shares-outstanding/605-26-gen/605-26-gen-testcase.xml': 1047.334,
    '605-instance-syntax/605-26-common-shares-outstanding/605-26-gen1/605-26-common-shares-outstanding-gen-testcase.xml': 189.204,
    '605-instance-syntax/605-26-common-shares-outstanding/605-26-man/605-26-man-testcase.xml': 34.115,
    '605-instance-syntax/605-27-footnote-no-substitutions/605-27-footnote-no-substitutions-testcase.xml': 1.936,
    '605-instance-syntax/605-28-footnote-no-custom-footnote-role/605-28-footnote-no-custom-footnote-role-testcase.xml': 1.187,
    '605-instance-syntax/605-29-footnote-loc-role-not-custom/605-29-footnote-loc-role-not-custom-testcase.xml': 0.516,
    '605-instance-syntax/605-32-footnote-loc-fragment-portable/605-32-footnote-loc-fragment-portable-testcase.xml': 0.320,
    '605-instance-syntax/605-33-footnote-linked-to-facts/605-33-footnote-linked-to-facts-testcase.xml': 1.239,
    '605-instance-syntax/605-34-footnote-xhtml/605-34-footnote-xhtml-testcase.xml': 3.138,
    '605-instance-syntax/605-35-numeric-units/605-35-numeric-units-testcase.xml': 30.848,
    '605-instance-syntax/605-36-measure-local-name/605-36-measure-local-name-testcase.xml': 5.809,
    '605-instance-syntax/605-37-nonzero-truncation/605-37-nonzero-truncation-testcase.xml': 2.110,
    '605-instance-syntax/605-38-forever-period/605-38-forever-period-testcase.xml': 0.364,
    '605-instance-syntax/605-39-dimensions/605-39-dimensions-testcase.xml': 1.386,
    '605-instance-syntax/605-40-submission-header/605-40-gen/605-40-gen-testcase.xml': 2210.828,
    '605-instance-syntax/605-40-submission-header/605-40-man/605-40-submission-header-man-testcase.xml': 308.204,
    '605-instance-syntax/605-40-submission-header/605-40-man1/605-40-man-testcase.xml': 200.192,
    '605-instance-syntax/605-41-seriesid/605-41-seriesid-testcase.xml': 6.729,
    '605-instance-syntax/605-42-deprecated/605-42-deprecated-testcase.xml': 11.183,
    '605-instance-syntax/605-43-signs/605-43-signs-testcase.xml': 9.639,
    '605-instance-syntax/605-44-custom-axis/605-44-custom-axis-testcase.xml': 2.192,
    '605-instance-syntax/605-45-cover-page-facts-general-case/605-45-cover-page-facts-general-case-testcase.xml': 0.000,
    '605-instance-syntax/605-46-registered-securities-cover-page-elts/605-46-gen/605-46-gen-testcase.xml': 243.216,
    '605-instance-syntax/605-46-registered-securities-cover-page-elts/605-46-man/605-46-man-testcase.xml': 79.700,
    '605-instance-syntax/605-47-company-id-cover-page-elts/605-47-gen/605-47-gen-testcase.xml': 165.815,
    '605-instance-syntax/605-47-company-id-cover-page-elts/605-47-man/605-47-man-testcase.xml': 38.432,
    '605-instance-syntax/605-48-cover-page-principal-office-elts/605-48-gen/605-48-gen-testcase.xml': 351.629,
    '605-instance-syntax/605-48-cover-page-principal-office-elts/605-48-man/605-48-man-testcase.xml': 23.944,
    '605-instance-syntax/605-49-cover-page-etls-and-sub-type/605-49-gen/605-49-gen-testcase.xml': 553.309,
    '605-instance-syntax/605-49-cover-page-etls-and-sub-type/605-49-man/605-49-man-testcase.xml': 92.298,
    '605-instance-syntax/605-50-form-20-f-cover-page-elts/605-50-gen/605-50-gen-testcase.xml': 135.923,
    '605-instance-syntax/605-50-form-20-f-cover-page-elts/605-50-man/605-50-man-testcase.xml': 12.211,
    '605-instance-syntax/605-51-business-contact-etls/605-51-gen/605-51-gen-testcase.xml': 405.606,
    '605-instance-syntax/605-51-business-contact-etls/605-51-man/605-51-man-testcase.xml': 54.415,
    '605-instance-syntax/605-52-form-8-k-cover-page-and-name-changes-elts/605-52-gen/605-52-gen-testcase.xml': 263.453,
    '605-instance-syntax/605-52-form-8-k-cover-page-and-name-changes-elts/605-52-man/605-52-man-testcase.xml': 4.679,
    '605-instance-syntax/605-53-former-address-cover-page-elts/605-53-gen/605-53-gen-testcase.xml': 328.627,
    '605-instance-syntax/605-53-former-address-cover-page-elts/605-53-man/605-53-man-testcase.xml': 3.012,
    '605-instance-syntax/605-54-auditor-information/605-54-auditor-information-testcase.xml': 63.350,
    '605-instance-syntax/605-55-cover-page-form-N-2/605-55-cover-page-form-N-2-testcase.xml': 65.478,
    '605-instance-syntax/605-56-prospectus-document-types/605-56-prospectus-document-types-testcase.xml': 37.016,
    '605-instance-syntax/605-57-N-1A-Fund-Shareholder-Reports/605-57-N-1A-Fund-Shareholder-Reports-testcase.xml': 78.442,
    '605-instance-syntax/605-58-Resource-Extraction-Payments-Form-SD-Exhibit-201/605-58-Resource-Extraction-Payments-Form-SD-Exhibit-201-testcase.xml': 12.570,
    '607-schema-syntax/607-01-no-include/607-01-no-include-testcase.xml': 0.659,
    '607-schema-syntax/607-03-ext-not-standard-namespace/607-03-ext-not-standard-namespace-testcase.xml': 2.519,
    '607-schema-syntax/607-04-valid-ext-namespace-format/607-04-valid-ext-namespace-format-testcase.xml': 3.332,
    '607-schema-syntax/607-07-recommended-prefix-required/607-07-recommended-prefix-required-testcase.xml': 1.738,
    '607-schema-syntax/607-09-role-authority-matches-namespace/607-09-role-authority-matches-namespace-testcase.xml': 1.636,
    '607-schema-syntax/607-10-role-types-no-duplicates/607-10-role-types-no-duplicates-testcase.xml': 0.879,
    '607-schema-syntax/607-11-role-types-pre-cal-def/607-11-role-types-pre-cal-def-testcase.xml': 1.752,
    '607-schema-syntax/607-12-role-has-definition/607-12-role-has-definition-testcase.xml': 3.864,
    '607-schema-syntax/607-13-arcrole-authority-matches-namespace/607-13-arcrole-authority-matches-namespace-testcase.xml': 1.352,
    '607-schema-syntax/607-14-arcrole-types-no-duplicates/607-14-arcrole-types-no-duplicates-testcase.xml': 0.794,
    '607-schema-syntax/607-15-arcrole-has-definition/607-15-arcrole-has-definition-testcase.xml': 0.899,
    '607-schema-syntax/607-16-no-ext-name-same-as-base/607-16-no-ext-name-same-as-base-testcase.xml': 2.603,
    '607-schema-syntax/607-17-valid-ext-elt-id/607-17-valid-ext-elt-id-testcase.xml': 1.392,
    '607-schema-syntax/607-18-nillable-true/607-18-nillable-true-testcase.xml': 0.893,
    '607-schema-syntax/607-19-no-ext-elt-tuples/607-19-no-ext-elt-tuples-testcase.xml': 0.473,
    '607-schema-syntax/607-20-no-typed-domain-ref/607-20-no-typed-domain-ref-testcase.xml': 0.489,
    '607-schema-syntax/607-21-abstracts-duration/607-21-abstracts-duration-testcase.xml': 0.481,
    '607-schema-syntax/607-23-dimensions-named-axis/607-23-dimensions-named-axis-testcase.xml': 0.840,
    '607-schema-syntax/607-24-hypercubes-named-table/607-24-hypercubes-named-table-testcase.xml': 0.928,
    '607-schema-syntax/607-25-no-custom-substitutiongroups/607-25-no-custom-substitutiongroups-testcase.xml': 0.896,
    '607-schema-syntax/607-26-lineitems-abstract/607-26-lineitems-abstract-testcase.xml': 0.931,
    '607-schema-syntax/607-27-domain-member-type/607-27-domain-member-type-testcase.xml': 3.486,
    '607-schema-syntax/607-28-domain-member-duration/607-28-domain-member-duration-testcase.xml': 0.866,
    '607-schema-syntax/607-29-name-length/607-29-name-length-testcase.xml': 4.483,
    '607-schema-syntax/607-30-uri-length/607-30-uri-length-testcase.xml': 2.259,
    '607-schema-syntax/607-31-fraction-item-type/607-31-fraction-item-type-testcase.xml': 1.079,
    '607-schema-syntax/607-32-nonnumeric-instant/607-32-nonnumeric-instant-testcase.xml': 1.061,
    '609-linkbase-syntax/609-03-no-ineffectual-arcs/609-03-no-ineffectual-arcs-testcase.xml': 7.555,
    '609-linkbase-syntax/609-04-no-missing-default-roles/609-04-no-missing-default-roles-testcase.xml': 0.471,
    '609-linkbase-syntax/609-05-no-custom-resource-roles/609-05-no-custom-resource-roles-testcase.xml': 1.214,
    '609-linkbase-syntax/609-06-no-custom-arcroles/609-06-no-custom-arcroles-testcase.xml': 0.883,
    '609-linkbase-syntax/609-07-linkbases-distinct/609-07-linkbases-distinct-testcase.xml': 0.459,
    '609-linkbase-syntax/609-09-priority-less-than-ten/609-09-priority-less-than-ten-testcase.xml': 2.674,
    '609-linkbase-syntax/609-10-general-namespace-specific-custom-arc-restrictions/609-10-general-namespace-specific-custom-arc-restrictions-testcase.xml': 0.000,
    '610-label-syntax/610-01-element-used-has-label/610-01-element-used-has-label-testcase.xml': 2.802,
    '610-label-syntax/610-02-element-used-one-label-per-role/610-02-element-used-one-label-per-role-testcase.xml': 2.751,
    '610-label-syntax/610-03-foreign-label-requires-english/610-03-foreign-label-requires-english-testcase.xml': 4.006,
    '610-label-syntax/610-04-distinct-standard-labels/610-04-distinct-standard-labels-testcase.xml': 1.858,
    '610-label-syntax/610-05-no-documentation-replacement/610-05-no-documentation-replacement-testcase.xml': 0.933,
    '610-label-syntax/610-06-no-special-chars-unless-documentation/610-06-no-special-chars-unless-documentation-testcase.xml': 2.078,
    '610-label-syntax/610-08-label-is-trimmed/610-08-label-is-trimmed-testcase.xml': 1.302,
    '610-label-syntax/610-09-nonnumeric-label-role/610-09-nonnumeric-label-testcase.xml': 6.883,
    '612-presentation-syntax/612-01-presentation-order-required/612-01-presentation-order-required-testcase.xml': 0.484,
    '612-presentation-syntax/612-02-presentation-order-distinct/612-02-presentation-order-distinct-testcase.xml': 1.003,
    '612-presentation-syntax/612-03-element-used-is-presented/612-03-element-used-is-presented-testcase.xml': 2.723,
    '612-presentation-syntax/612-05-distinct-preferred-labels/612-05-distinct-preferred-labels-testcase.xml': 1.797,
    '612-presentation-syntax/612-06-presentation-single-root/612-06-presentation-single-root-testcase.xml': 1.152,
    '612-presentation-syntax/612-07-period-type-preferred-label-mismatch/612-07-period-type-preferred-label-mismatch-testcase.xml': 2.019,
    '612-presentation-syntax/612-08-axis-requires-domain-child/612-08-axis-requires-domain-child-testcase.xml': 0.657,
    '612-presentation-syntax/612-09-presented-units-order/612-09-presented-units-order-testcase.xml': 1.150,
    '612-presentation-syntax/612-10-cef-presentation-link-validations/612-10-cef-presentation-link-validations-testcase.xml': 8.692,
    '612-presentation-syntax/612-11-vip-presentation-link-validations/612-11-vip-presentation-link-validations-testcase.xml': 1.836,
    '614-calculation-syntax/614-01-calculation-order-required/614-01-calculation-order-required-testcase.xml': 0.369,
    '614-calculation-syntax/614-02-calculation-is-unitary/614-02-calculation-is-unitary-testcase.xml': 0.483,
    '614-calculation-syntax/614-03-calculation-same-period-types/614-03-calculation-same-period-types-testcase.xml': 0.473,
    '614-calculation-syntax/614-04-summation-item-undirected/614-04-summation-item-undirected-testcase.xml': 1.499,
    '614-calculation-syntax/614-05-calculation-has-presentation-same-base-set/614-05-calculation-has-presentation-same-base-set-testcase.xml': 4.556,
    '614-calculation-syntax/614-06-cef-calculation-link-validations/614-06-cef-calculation-link-validations-testcase.xml': 3.371,
    '614-calculation-syntax/614-07-vip-calculation-link-validations/614-07-vip-calculation-link-validations-testcase.xml': 1.346,
    '614-calculation-syntax/614-08-ecd-calculation-link-validations/614-08-ecd-calculation-link-validations-testcase.xml': 3.609,
    '616-definition-syntax/616-01-definition-relationship-has-order/616-01-definition-relationship-has-order-testcase.xml': 0.366,
    '616-definition-syntax/616-03-dimension-domain-is-domain/616-03-dimension-domain-is-domain-testcase.xml': 1.019,
    '616-definition-syntax/616-04-domain-member-no-cycles/616-04-domain-member-no-cycles-testcase.xml': 6.145,
    '616-definition-syntax/616-05-one-all-per-base-set/616-05-one-all-per-base-set-testcase.xml': 0.958,
    '616-definition-syntax/616-06-notall-must-have-closed-false/616-06-notall-must-have-closed-false-testcase.xml': 0.477,
    '616-definition-syntax/616-07-notall-axis-requires-all/616-07-notall-axis-requires-all-testcase.xml': 0.841,
    '616-definition-syntax/616-08-notall-all-are-distinct/616-08-notall-all-are-distinct-testcase.xml': 0.938,
    '616-definition-syntax/616-09-consecutive-relationship-required/616-09-consecutive-relationship-required-testcase.xml': 1.896,
    '616-definition-syntax/616-10-cef-definition-link-validations/616-10-cef-definition-link-validations-testcase.xml': 10.301,
    '616-definition-syntax/616-11-vip-definition-link-validations/616-11-vip-definition-link-validations-testcase.xml': 3.088,
    '616-definition-syntax/616-12-ecd-definition-link-validations/616-12-ecd-definition-link-validations-testcase.xml': 9.182,
    '618-reference-syntax/618-01-no-custom-references/618-01-no-custom-references-testcase.xml': 0.995,
    '618-reference-syntax/618-02-no-added-references/618-02-no-added-references-testcase.xml': 0.456,
    '622-only-supported-locations/622-01-all-supported-locations/622-01-all-supported-locations-testcase.xml': 33.815,
    '622-only-supported-locations/622-02-no-unsupported-locations/622-02-no-unsupported-locations-testcase.xml': 134.717,
    '622-only-supported-locations/622-03-consistent-locations/622-03-consistent-locations-testcase.xml': 63.367,
    '622-only-supported-locations/622-05-ix-no-unsupported-locations/622-05-ix-no-unsupported-locations-testcase.xml': 1.838,
    '624-rendering/01-presentation-groups/gd/01-presentation-groups-gd-testcase.xml': 0.941,
    '624-rendering/02-contexts/gd/02-contexts-gd-testcase.xml': 1.101,
    '624-rendering/03-unit-selection/gd/03-unit-selection-gd-testcase.xml': 0.404,
    '624-rendering/04-primary-axis/gd/04-primary-axis-gd-testcase.xml': 0.393,
    '624-rendering/05-fact-selection/gd/05-fact-selection-gd-testcase.xml': 0.420,
    '624-rendering/06-layout/gd/06-layout-gd-testcase.xml': 10.572,
    '624-rendering/07-member-ordering/gd/07-member-ordering-gd-testcase.xml': 12.055,
    '624-rendering/08-merged-columns/gd/08-merged-columns-gd-testcase.xml': 4.000,
    '624-rendering/09-start-end-labels/gd/09-start-end-labels-gd-testcase.xml': 0.000,
    '624-rendering/10-column-headings/gd/10-column-headings-gd-testcase.xml': 0.844,
    '624-rendering/11-row-headings/gd/11-row-headings-gd-testcase.xml': 0.284,
    '624-rendering/12-footnotes/gd/12-footnotes-gd-testcase.xml': 3.501,
    '624-rendering/13-flow-through/gd/13-flow-through-gd-testcase.xml': 3.703,
    '624-rendering/14-cash-flows/gd/14-cash-flows-gd-testcase.xml': 0.000,
    '624-rendering/15-equity-changes/gd/15-equity-changes-gd-testcase.xml': 6.470,
    '624-rendering/15-equity-changes/gw/15-equity-changes-gw-testcase.xml': 0.000,
    '624-rendering/16-qualifiers/gd/16-qualifiers-gd-testcase.xml': 0.342,
    '624-rendering/17-uncategorized-facts/gd/17-uncategorized-facts-gd-testcase.xml': 0.508,
    '624-rendering/18-numeric/gd/18-numeric-gd-testcase.xml': 0.000,
    '624-rendering/19-nonnumeric/gd/19-nonnumeric-gd-testcase.xml': 11.335,
    '624-rendering/20-filing-summary/gd/20-filing-summary-gd-testcase.xml': 1.376,
    '624-rendering/21-multiple/gd/21-multiple-gd-testcase.xml': 0.411,
    '624-rendering/22-workbook/gd/22-workbook-gd-testcase.xml': 0.455,
    '624-rendering/624-23-Resource-Extraction-Payment-Rendering/624-23-Resource-Extraction-Payment-Rendering-testcase.xml': 1.230,
    '625-rr-rendering/01-embedding-commands/gd/01-embedding-commands-gd-testcase.xml': 1.925,
    '625-rr-rendering/02-bar-charts/gd/02-bar-charts-gd-testcase.xml': 0.740,
    '626-rendering-syntax/626-01-all-facts-filtered/626-01-all-facts-filtered-testcase.xml': 1.164,
    '626-rendering-syntax/626-02-instant-without-matching-duration/626-02-instant-without-matching-duration-testcase.xml': 1.724,
    '626-rendering-syntax/626-03-no-matching-durations/626-03-no-matching-durations-testcase.xml': 3.413,
    '626-rendering-syntax/626-04-embedding-command-syntax/626-04-embedding-command-syntax-testcase.xml': 6.736,
    '626-rendering-syntax/626-05-embedding-missing-rows-or-columns/626-05-embedding-missing-rows-or-columns-testcase.xml': 4.074,
    '626-rendering-syntax/626-06-embedding-incomplete-ordering-axes/626-06-embedding-incomplete-ordering-axes-testcase.xml': 0.806,
    '626-rendering-syntax/626-07-empty-bar-chart/626-07-empty-bar-chart-testcase.xml': 0.722,
    '626-rendering-syntax/626-08-too-many-annual-return-facts/626-08-too-many-annual-return-facts-testcase.xml': 0.716,
    '626-rendering-syntax/626-09-Primary-Axis-On-Rows/626-09-primary-axis-on-rows-testcase.xml': 0.796,
    '902-sdr/efm/60302-sdr-doctype/60302-sdr-doctype-testcase.xml': 60.076,
    '902-sdr/efm/60524-sdr-registrant-name/60524-sdr-registrant-name-testcase.xml': 21.024,
    '902-sdr/efm/62421-sdr-multiple/62421-sdr-multiple-testcase.xml': 8.248,
    'filing-fee-exhibit/000-schema/01-valueError/00-bad/00-bad-testcase.xml': 57.198,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/01-RegnFileNb/01-RegnFileNb-testcase.xml': 0.600,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/05-IssrNm/05-IssrNm-testcase.xml': 0.586,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/06-IssrBizAdrStrt1/06-IssrBizAdrStrt1-testcase.xml': 0.566,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/08-IssrBizAdrCity/08-IssrBizAdrCity-testcase.xml': 0.210,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/09-IssrBizAdrStatOrCtryCd/09-IssrBizAdrStatOrCtryCd-testcase.xml': 0.348,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/10-IssrBizAdrZipCd/10-IssrBizAdrZipCd-testcase.xml': 0.225,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/11-CeasedOprsDt/11-CeasedOprsDt-testcase.xml': 0.342,
    'filing-fee-exhibit/100-submissionTable/02-424ISubmissions/12-RptgFsclYrEndDt/12-RptgFsclYrEndDt-testcase.xml': 1.119,
    'filing-fee-exhibit/200-feesSummaryTable/01-424ISubmissions/03-TtlFeeAmt/03-TtlFeeAmt-testcase.xml': 0.785,
    'filing-fee-exhibit/200-feesSummaryTable/01-424ISubmissions/05-FeeIntrstAmt/05-FeeIntrstAmt-testcase.xml': 0.901,
    'filing-fee-exhibit/200-feesSummaryTable/01-424ISubmissions/08-NetFeeAmt/08-NetFeeAmt-testcase.xml': 0.204,
    'filing-fee-exhibit/200-feesSummaryTable/01-424ISubmissions/12-TtlFeeAndIntrstAmt/12-TtlFeeAndIntrstAmt-testcase.xml': 0.917,
    'filing-fee-exhibit/200-feesSummaryTable/03-OtherSubmissions/01-TtlOfferingAmt/01-TtlOfferingAmt-testcase.xml': 1.836,
    'filing-fee-exhibit/200-feesSummaryTable/03-OtherSubmissions/04-TtlTxValtn/04-TtlTxValtn-testcase.xml': 0.211,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/00-flagIssues/00-flagIssues-testcase.xml': 2.190,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/00-good/00-good-testcase.xml': 2.168,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 3.536,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 4.395,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 4.230,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 4.363,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 4.243,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 6.389,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/08-FeeRate/08-FeeRate-testcase.xml': 5.313,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/09-FeeAmt/09-FeeAmt-testcase.xml': 6.743,
    'filing-fee-exhibit/300-offeringTable/01-Rule457(a)/21-OfferingNote/21-OfferingNote-testcase.xml': 2.284,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/00-flagIssues/00-flagIssues-testcase.xml': 2.218,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/00-good/00-good-testcase.xml': 2.235,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 3.589,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 5.574,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 5.499,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 2.262,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 4.314,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 4.424,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/08-FeeRate/08-FeeRate-testcase.xml': 5.172,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/09-FeeAmt/09-FeeAmt-testcase.xml': 6.487,
    'filing-fee-exhibit/300-offeringTable/02-Rule457(o)/21-OfferingNote/21-OfferingNote-testcase.xml': 2.121,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/00-flagIssues/00-flagIssues-testcase.xml': 0.901,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/00-good/00-good-testcase.xml': 0.767,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 1.110,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 1.670,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 1.514,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 1.404,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 1.635,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 1.498,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/08-FeeRate/08-FeeRate-testcase.xml': 1.414,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/09-FeeAmt/09-FeeAmt-testcase.xml': 1.619,
    'filing-fee-exhibit/300-offeringTable/03-Rule457(r)/21-OfferingNote/21-OfferingNote-testcase.xml': 1.493,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/00-flagIssues/00-flagIssues-testcase.xml': 1.393,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/00-good/00-good-testcase.xml': 1.291,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 1.630,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 2.605,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 2.726,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 1.456,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 1.314,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 2.609,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/08-FeeRate/08-FeeRate-testcase.xml': 2.499,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/09-FeeAmt/09-FeeAmt-testcase.xml': 2.600,
    'filing-fee-exhibit/300-offeringTable/04-Rule457(s)/21-OfferingNote/21-OfferingNote-testcase.xml': 2.702,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/00-flagIssues/00-flagIssues-testcase.xml': 0.897,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/00-good/00-good-testcase.xml': 0.761,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 1.303,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 1.671,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 1.608,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 0.749,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 0.777,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 0.888,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/08-FeeRate/08-FeeRate-testcase.xml': 0.746,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/09-FeeAmt/09-FeeAmt-testcase.xml': 0.872,
    'filing-fee-exhibit/300-offeringTable/05-Rule457(u)/21-OfferingNote/21-OfferingNote-testcase.xml': 1.611,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/00-flagIssues/00-flagIssues-testcase.xml': 2.032,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/00-good/00-good-testcase.xml': 2.147,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 3.408,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 3.478,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 4.220,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 2.210,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 2.210,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 2.105,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/08-FeeRate/08-FeeRate-testcase.xml': 2.985,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/09-FeeAmt/09-FeeAmt-testcase.xml': 4.321,
    'filing-fee-exhibit/300-offeringTable/06-Ruleother/21-OfferingNote/21-OfferingNote-testcase.xml': 4.193,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/00-flagIssues/00-flagIssues-testcase.xml': 2.372,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/00-good/00-good-testcase.xml': 2.372,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 4.041,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 4.935,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 2.428,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/06-MaxAggtOfferingPric/06-MaxAggtOfferingPric-testcase.xml': 2.371,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/08-FeeRate/08-FeeRate-testcase.xml': 2.382,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/10-CfwdPrrFileNb/10-CfwdPrrFileNb-testcase.xml': 4.698,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/11-CfwdFormTp/11-CfwdFormTp-testcase.xml': 7.227,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/12-CfwdPrrFctvDt/12-CfwdPrrFctvDt-testcase.xml': 4.823,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/13-CfwdPrevslyPdFee/13-CfwdPrevslyPdFee-testcase.xml': 4.713,
    'filing-fee-exhibit/300-offeringTable/07-Rule415(a)(6)/21-OfferingNote/21-OfferingNote-testcase.xml': 2.543,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/00-good/00-good-testcase.xml': 0.555,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 0.775,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/07-TxValtn/07-TxValtn-testcase.xml': 0.914,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/08-FeeRate/08-FeeRate-testcase.xml': 1.148,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/09-FeeAmt/09-FeeAmt-testcase.xml': 1.004,
    'filing-fee-exhibit/300-offeringTable/08-Rule0-11/21-OfferingNote/21-OfferingNote-testcase.xml': 1.142,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/00-good/00-good-testcase.xml': 2.073,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/01-PrevslyPdFlg/01-PrevslyPdFlg-testcase.xml': 6.849,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/02-OfferingSctyTp/02-OfferingSctyTp-testcase.xml': 1.909,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/03-OfferingSctyTitl/03-OfferingSctyTitl-testcase.xml': 3.974,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/04-AmtSctiesRegd/04-AmtSctiesRegd-testcase.xml': 1.937,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/05-MaxOfferingPricPerScty/05-MaxOfferingPricPerScty-testcase.xml': 1.946,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/08-FeeRate/08-FeeRate-testcase.xml': 1.897,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/15-AmtSctiesRcvd/15-AmtSctiesRcvd-testcase.xml': 2.026,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/16-ValSctiesRcvdPerShr/16-ValSctiesRcvdPerShr-testcase.xml': 1.907,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/20-FeeNoteMaxAggtOfferingPric/20-FeeNoteMaxAggtOfferingPric-testcase.xml': 1.865,
    'filing-fee-exhibit/300-offeringTable/09-Rule457(f)/21-OfferingNote/21-OfferingNote-testcase.xml': 1.907,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/00-flagIssues/00-flagIssues-testcase.xml': 2.071,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/00-good/00-good-testcase.xml': 1.929,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/01-OffsetClmdInd/01-OffsetClmdInd-testcase.xml': 3.853,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/02-OffsetPrrFilerNm/02-OffsetPrrFilerNm-testcase.xml': 5.902,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/03-OffsetPrrFormTp/03-OffsetPrrFormTp-testcase.xml': 4.043,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/04-OffsetPrrFileNb/04-OffsetPrrFileNb-testcase.xml': 3.909,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/05-OffsetClmInitlFilgDt/05-OffsetClmInitlFilgDt-testcase.xml': 10.181,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/06-OffsetSrcFilgDt/06-OffsetSrcFilgDt-testcase.xml': 7.817,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/07-OffsetClmdAmt/07-OffsetClmdAmt-testcase.xml': 7.878,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/12-OffsetPrrFeeAmt/12-OffsetPrrFeeAmt-testcase.xml': 5.869,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/13-OffsetExpltnForClmdAmt/13-OffsetExpltnForClmdAmt-testcase.xml': 4.072,
    'filing-fee-exhibit/400-offsetTable/01-Rule457(b)/14-OffsetNote/14-OffsetNote-testcase.xml': 1.939,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/00-flagIssues/00-flagIssues-testcase.xml': 1.920,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/00-good/00-good-testcase.xml': 2.040,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/01-OffsetClmdInd/01-OffsetClmdInd-testcase.xml': 3.853,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/02-OffsetPrrFilerNm/02-OffsetPrrFilerNm-testcase.xml': 5.962,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/03-OffsetPrrFormTp/03-OffsetPrrFormTp-testcase.xml': 3.793,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/04-OffsetPrrFileNb/04-OffsetPrrFileNb-testcase.xml': 4.162,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/05-OffsetClmInitlFilgDt/05-OffsetClmInitlFilgDt-testcase.xml': 10.190,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/06-OffsetSrcFilgDt/06-OffsetSrcFilgDt-testcase.xml': 8.355,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/07-OffsetClmdAmt/07-OffsetClmdAmt-testcase.xml': 8.162,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/12-OffsetPrrFeeAmt/12-OffsetPrrFeeAmt-testcase.xml': 5.968,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/13-OffsetExpltnForClmdAmt/13-OffsetExpltnForClmdAmt-testcase.xml': 4.009,
    'filing-fee-exhibit/400-offsetTable/02-Rule0-11(a)(2)/14-OffsetNote/14-OffsetNote-testcase.xml': 1.953,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/00-flagIssues/00-flagIssues-testcase.xml': 2.030,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/00-good/00-good-testcase.xml': 2.011,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/01-OffsetClmdInd/01-OffsetClmdInd-testcase.xml': 4.416,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/02-OffsetPrrFilerNm/02-OffsetPrrFilerNm-testcase.xml': 6.425,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/03-OffsetPrrFormTp/03-OffsetPrrFormTp-testcase.xml': 3.991,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/04-OffsetPrrFileNb/04-OffsetPrrFileNb-testcase.xml': 6.154,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/05-OffsetClmInitlFilgDt/05-OffsetClmInitlFilgDt-testcase.xml': 8.317,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/06-OffsetSrcFilgDt/06-OffsetSrcFilgDt-testcase.xml': 7.916,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/07-OffsetClmdAmt/07-OffsetClmdAmt-testcase.xml': 8.325,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/08-OffsetPrrSctyTp/08-OffsetPrrSctyTp-testcase.xml': 2.148,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/09-OffsetPrrSctyTitl/09-OffsetPrrSctyTitl-testcase.xml': 3.981,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/10-OffsetPrrNbOfUnsoldScties/10-OffsetPrrNbOfUnsoldScties-testcase.xml': 2.159,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/11-OffsetPrrUnsoldOfferingAmt/11-OffsetPrrUnsoldOfferingAmt-testcase.xml': 2.239,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/12-OffsetPrrFeeAmt/12-OffsetPrrFeeAmt-testcase.xml': 6.038,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/14-OffsetNote/14-OffsetNote-testcase.xml': 1.983,
    'filing-fee-exhibit/400-offsetTable/03-Rule457(p)/15-TermntnCmpltnWdrwl/15-TermntnCmpltnWdrwl-testcase.xml': 4.571,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/00-flagIssues/00-flagIssues-testcase.xml': 1.988,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/00-good/00-good-testcase.xml': 2.000,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/01-Rule429EarlierFileNb/01-Rule429EarlierFileNb-testcase.xml': 5.997,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/02-Rule429EarlierFormTp/02-Rule429EarlierFormTp-testcase.xml': 3.909,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/03-Rule429InitlFctvDt/03-Rule429InitlFctvDt-testcase.xml': 5.924,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/04-Rule429SctyTp/04-Rule429SctyTp-testcase.xml': 3.891,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/05-Rule429SctyTitl/05-Rule429SctyTitl-testcase.xml': 5.895,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/06-Rule429NbOfUnsoldScties/06-Rule429NbOfUnsoldScties-testcase.xml': 1.951,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/07-Rule429AggtOfferingAmt/07-Rule429AggtOfferingAmt-testcase.xml': 1.952,
    'filing-fee-exhibit/500-cmbndPrspctsTable/01-Rule429/08-Rule429PrspctsNote/08-Rule429PrspctsNote-testcase.xml': 1.964,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/00-good/00-good-testcase.xml': 0.356,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/02-OfferingSctyTitl/02-OfferingSctyTitl-testcase.xml': 0.569,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/03-AggtSalesPricFsclYr/03-AggtSalesPricFsclYr-testcase.xml': 0.438,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/04-AggtRedRpPricFsclYr/04-AggtRedRpPricFsclYr-testcase.xml': 0.575,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/05-AggtRedRpPricPrrFsclYr/05-AggtRedRpPricPrrFsclYr-testcase.xml': 0.560,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/06-AmtRedCdts/06-AmtRedCdts-testcase.xml': 0.343,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/07-NetSalesAmt/07-NetSalesAmt-testcase.xml': 1.165,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/08-FeeRate/08-FeeRate-testcase.xml': 0.454,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/09-FeeAmt/09-FeeAmt-testcase.xml': 0.585,
    'filing-fee-exhibit/600-Scties424iTable/01-Rule424/10-FeeNote/10-FeeNote-testcase.xml': 0.347,
}.items()}

config = ConformanceSuiteConfig(
    additional_plugins_by_prefix=[
        ('conf/612-presentation-syntax/612-09-presented-units-order', frozenset({'EdgarRenderer'})),
        ('conf/626-rendering-syntax', frozenset({'EdgarRenderer'})),
    ],
    approximate_relative_timing=TIMING,
    args=[
        '--disclosureSystem', 'efm-pragmatic',
        '--formula', 'run',
    ],
    expected_empty_testcases=frozenset(f'conf/{s}' for s in [
        '605-instance-syntax/605-45-cover-page-facts-general-case/605-45-cover-page-facts-general-case-testcase.xml',
        '609-linkbase-syntax/609-10-general-namespace-specific-custom-arc-restrictions/609-10-general-namespace-specific-custom-arc-restrictions-testcase.xml',
        '624-rendering/09-start-end-labels/gd/09-start-end-labels-gd-testcase.xml',
        '624-rendering/14-cash-flows/gd/14-cash-flows-gd-testcase.xml',
        '624-rendering/15-equity-changes/gw/15-equity-changes-gw-testcase.xml',
        '624-rendering/18-numeric/gd/18-numeric-gd-testcase.xml',
        '626-rendering-syntax/626-03-no-matching-durations/626-03-no-matching-durations-testcase.xml',
    ]),
    file='conf/testcases.xml',
    info_url='https://www.sec.gov/structureddata/osdinteractivedatatestsuite',
    local_filepath='efm-68-1-240129.zip',
    name=PurePath(__file__).stem,
    plugins=frozenset({'validate/EFM', 'inlineXbrlDocumentSet'}),
    public_download_url='https://www.sec.gov/files/efm-68-1-240129.zip',
    shards=40,
    # efm-68-1-240129.zip test suite has case sensitive errors when referring to test case files.
    # 'OEF' and 'RXP' are uppercase in directory names and lowercase in test suite URIs.
    strict_testcase_index=False,
)



from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig

TIMING = {f'XBRL-CONF-2014-12-10/Common/{k}': v for k, v in {
    '100-schema/102-item.xml': 0.062,
    '100-schema/103-type.xml': 0.006,
    '100-schema/104-tuple.xml': 0.162,
    '100-schema/105-balance.xml': 0.032,
    '100-schema/106-targetNamespace.xml': 0.023,
    '100-schema/107-DTSWithLinkbaseInSchema.xml': 0.006,
    '100-schema/114-lax-validation-testcase.xml': 0.029,
    '100-schema/115-ArcroleAndRoleRefs-testcase.xml': 0.028,
    '100-schema/155-TypeExtension.xml': 0.006,
    '100-schema/160-UsedOn.xml': 0.055,
    '100-schema/161-Appinfo.xml': 0.027,
    '200-linkbase/201-linkref.xml': 0.084,
    '200-linkbase/202-xlinkLocator.xml': 0.142,
    '200-linkbase/204-arcCycles.xml': 0.247,
    '200-linkbase/205-roleDeclared.xml': 0.088,
    '200-linkbase/206-arcDeclared.xml': 0.078,
    '200-linkbase/207-arcDeclaredCycles.xml': 0.145,
    '200-linkbase/208-balance.xml': 0.076,
    '200-linkbase/209-Arcs.xml': 0.040,
    '200-linkbase/210-relationshipEquivalence.xml': 0.044,
    '200-linkbase/211-Testcase-sEqualUsedOn.xml': 0.002,
    '200-linkbase/212-Testcase-linkbaseDocumentation.xml': 0.055,
    '200-linkbase/213-SummationItemArcEndpoints.xml': 0.021,
    '200-linkbase/214-lax-validation-testcase.xml': 0.029,
    '200-linkbase/215-ArcroleAndRoleRefs-testcase.xml': 0.071,
    '200-linkbase/220-NonStandardArcsAndTypes.xml': 0.058,
    '200-linkbase/230-CustomLinkbasesAndLocators.xml': 0.013,
    '200-linkbase/231-SyntacticallyEqualArcsThatAreNotEquivalentArcs.xml': 0.027,
    '200-linkbase/291-inferArcOverride.xml': 0.108,
    '200-linkbase/292-Embeddedlinkbaseinthexsd.xml': 0.037,
    '200-linkbase/293-UsedOn.xml': 0.043,
    '200-linkbase/preferredLabel.xml': 0.039,
    '300-instance/301-idScope.xml': 0.125,
    '300-instance/302-context.xml': 0.081,
    '300-instance/303-periodType.xml': 0.037,
    '300-instance/304-unitOfMeasure.xml': 0.225,
    '300-instance/305-decimalPrecision.xml': 0.063,
    '300-instance/306-required.xml': 0.024,
    '300-instance/307-schemaRef.xml': 0.020,
    '300-instance/308-ArcroleAndRoleRefs-testcase.xml': 0.014,
    '300-instance/314-lax-validation-testcase.xml': 0.042,
    '300-instance/320-CalculationBinding.xml': 0.326,
    '300-instance/321-internationalization.xml': 0.025,
    '300-instance/322-XmlXbrlInteraction.xml': 0.055,
    '300-instance/330-s-equal-testcase.xml': 0.155,
    '300-instance/331-equivalentRelationships-testcase.xml': 0.128,
    '300-instance/391-inferDecimalPrecision.xml': 20.331,
    '300-instance/392-inferEssenceAlias.xml': 0.170,
    '300-instance/395-inferNumericConsistency.xml': 0.063,
    '300-instance/397-Testcase-SummationItem.xml': 0.248,
    '300-instance/398-Testcase-Nillable.xml': 0.006,
    '400-misc/400-nestedElements.xml': 0.008,
    '400-misc/401-datatypes.xml': 0.014,
    'related-standards/xlink/arc-duplication/arc-duplication-testcase.xml': 0.029,
    'related-standards/xml-schema/uniqueParticleAttribution/uniqueParticleAttribution-testcase.xml': 0.033,
}.items()}

config = ConformanceSuiteConfig(
    approximate_relative_timing=TIMING,
    args=[
        '--formula', 'run',
        '--calcPrecision',
    ],
    expected_failure_ids=frozenset(f'XBRL-CONF-2014-12-10/Common/{s}' for s in [
        # 202.02b in the absence of source/target constraints, an empty href doesn't pose a problem
        # 202-02b-HrefResolutionCounterExample-custom.xml Expected: valid, Actual: arelle:hrefWarning
        '200-linkbase/202-xlinkLocator.xml:V-02b',
        # Tests that a decimals 0 value 0 is not treated as precision 0 (invalid) but as numeric zero.
        # In the prior approach where decimals 0 value 0 converted to precision 0 value 0, this would have been invalid.
        # 320-30-BindCalculationInferDecimals-instance.xbrl Expected: valid, Actual: xbrl.5.2.5.2:calcInconsistency
        '300-instance/320-CalculationBinding.xml:V-30',
        # Edge case tests that decimal rounding with is performed.
        # 320-31-BindCalculationInferDecimals-instance.xbrl Expected: valid, Actual: xbrl.5.2.5.2:calcInconsistency
        '300-instance/320-CalculationBinding.xml:V-31',
        # Checks that .5 rounds half to nearest even sum.
        # 320-32-BindCalculationInferDecimals-instance.xbrl Expected: invalid, Actual: valid
        '300-instance/320-CalculationBinding.xml:V-32',
        # Checks that .5 rounds half to nearest even regardless whether a processor uses float sum.
        # 320-34-BindCalculationInferDecimals-instance.xbrl Expected: valid, Actual: xbrl.5.2.5.2:calcInconsistency
        '300-instance/320-CalculationBinding.xml:V-34',
        # 397-28-PrecisionDifferentScales.xbrl Expected: valid, Actual: xbrl.5.2.5.2:calcInconsistency
        '300-instance/397-Testcase-SummationItem.xml:V-28',
    ]),
    file='XBRL-CONF-2014-12-10/xbrl.xml',
    info_url='https://specifications.xbrl.org/work-product-index-group-base-spec-base-spec.html',
    local_filepath='XBRL-CONF-2014-12-10.zip',
    name=PurePath(__file__).stem,
    network_or_cache_required=False,
    public_download_url='https://www.xbrl.org/2014/XBRL-CONF-2014-12-10.zip',
    shards=3,
)



from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig

TIMING = {f'formula/tests/{k}': v for k, v in {
    '10000 Formula/11021-Formula-StaticAnalysis-MissingConceptRule/11021_MissingConceptRule_testcase.xml': 0.296,
    '10000 Formula/11023-Formula-StaticAnalysis-MissingUnitConstructionRule/11023-MissingUnitRule_testcase.xml': 0.030,
    '10000 Formula/11025-Formula-StaticAnalysis-ConflictingAspectRules/11025-ConflictingAspectRules_testcase.xml': 0.039,
    '10000 Formula/11027-Formula-StaticAnalysis-MissingEntityIdentifierRule/11027-MissingEntityIdentifierRule_testcase.xml': 0.014,
    '10000 Formula/11028-Formula-StaticAnalysis-MissingPeriodRule/11028-MissingPeriodRule_testcase.xml': 0.014,
    '10000 Formula/11029-Formula-StaticAnalysis-incompleteConceptRule/11029-incompleteConceptRule_testcase.xml': 0.026,
    '10000 Formula/11041-Formula-StaticAnalysis-incompleteEntityIdentifierRule/11041-incompleteEntityIdentifierRule_testcase.xml': 0.044,
    '10000 Formula/11051-Formula-StaticAnalysis-incompletePeriodRule/11051-incompletePeriodRule_testcase.xml': 0.014,
    '10000 Formula/11062-Formula-StaticAnalysis-OCC-missingSAVForDimensionRule/11062-OCC-missingSAVForDimensionRule_testcase.xml': 0.043,
    '10000 Formula/11063-Formula-StaticAnalysis-MissingSAVForUnitRule/11063-missingSAVForUnitRule_testcase.xml': 0.014,
    '10000 Formula/11071-Formula-StaticAnalysis-badUsageOfDimensionRule/11071 Bad Usage Of Dimension Rules.xml': 0.054,
    '10000 Formula/11201-Formula-StaticAnalysis-unrecognisedAspectRule/11201-unrecognisedAspectRule_testcase.xml': 0.023,
    '10000 Formula/11202-Formula-StaticAnalysis-illegalUseOfUncoveredQName/11202-illegalUseOfUncoveredQName_testcase.xml': 0.014,
    '10000 Formula/11204-Formula-StaticAnalysis-sequenceSAVConflicts/11204-sequenceSAVConflicts_testcase.xml': 0.110,
    '10000 Formula/11205-Formula-StaticAnalysis-nonExistentSourceVariable/11205-nonExistentSourceVariable_testcase.xml': 0.052,
    '10000 Formula/11206-Formula-StaticAnalysis-bindEmptySourceVariable/11206-bindEmptySourceVariable_testcase.xml': 0.028,
    '10000 Formula/11207-Formula-StaticAnalysis-defaultAspectValueConflicts/11207-defaultAspectValueConflicts_testcase.xml': 0.011,
    '10000 Formula/12010-Formula-Processing-ConstructingFactValue/12010 Constructing fact value.xml': 0.547,
    '10000 Formula/12020-Formula-Processing-AspectRules/12020 Aspect Rules.xml': 0.224,
    '10000 Formula/12021-Formula-Processing-undefinedSAV/12021-undefinedSAV_testcase.xml': 0.057,
    '10000 Formula/12030-Formula-Processing-ConceptRules/12030 Concept Rules.xml': 0.046,
    '10000 Formula/12040-Formula-Processing-EntityRules/12040 Entity Rules.xml': 0.123,
    '10000 Formula/12050-Formula-Processing-PeriodRules/12050 Period Rules.xml': 0.354,
    '10000 Formula/12060-Formula-Processing-OCCRules/12060 OCC Rules.xml': 0.464,
    '10000 Formula/12061-Formula-Processing-DimensionRules/12061 Dimension Rules.xml': 1.970,
    '10000 Formula/12062-Formula-Processing-DimensionUncovered/12062 DimensionUncovered Rules.xml': 0.763,
    '10000 Formula/12070-Formula-Processing-UnitRules/12070 Unit Rules.xml': 0.303,
    '10000 Formula/12080-Formula-Processing-ConstructingAccuracy/12080 Constructing accuracy.xml': 0.142,
    '10000 Formula/14010-Formula-UseCases-BasicCalculation/14010 Use Cases Basic Calculation.xml': 0.053,
    '10000 Formula/14020-Formula-UseCases-Movement/14020 Use Cases Movement.xml': 0.069,
    '20000 Variables/21201-VariableStaticAnalysis-noCustomFunctionSignature/21201_noCustomFunctionSignature_testcase.xml': 0.045,
    '20000 Variables/21221-VariableStaticAnalysis-parameterNameClash/21221-parameterNameClash_testcase.xml': 0.012,
    '20000 Variables/21222-VariableStaticAnalysis-parameterCyclicDependencies/21222-parameterCyclicDependencies_testcase.xml': 0.024,
    '20000 Variables/21231-VariableStaticAnalysis-parameterTypeMismatch/21231-parameterTypeMismatch_testcase.xml': 0.040,
    '20000 Variables/21233-VariableStaticAnalysis-GeneralVariables/21233 General Variable Static Analysis.xml': 0.037,
    '20000 Variables/21241-VariableStaticAnalysis-FactVariables/21241 Fact Variable Static Analysis.xml': 0.013,
    '20000 Variables/21251-VariableStaticAnalysis-VariableSetDuplicateNames/21251 Variable Set Duplicate Names.xml': 0.090,
    '20000 Variables/21261-VariableStaticAnalysis-VariableFilterRelationships/21261 VariableFilter Relationship.xml': 0.041,
    '20000 Variables/21271-VariableStaticAnalysis-VariableSetFilterRelationships/21271 VariableSetFilter Relationship.xml': 0.040,
    '20000 Variables/21291-VariableStaticAnalysis-VariableSetRelationships/21291 VariableSet Relationship.xml': 0.039,
    '20000 Variables/21321-VariableStaticAnalysis-unkownAspectModel/21321-unkownAspectModel_testcase.xml': 0.022,
    '20000 Variables/21322-VariableStaticAnalysis-aspectModelMismatch/21322-aspectModelMismatch_testcase.xml': 0.040,
    '20000 Variables/21363-VariableStaticAnalysis-unresolvedDependency/21363-unresolvedDependency_testcase.xml': 0.035,
    '20000 Variables/21851-VariableStaticAnalysis-factVariableReferenceNotAllowed/21851-factVariableReferenceNotAllowed_testcase.xml': 0.027,
    '20000 Variables/21930-VariableStaticAnalysis-cyclicDependencies/21930-cyclicDependencies_testcase.xml': 0.014,
    '20000 Variables/22010-Variable-Processing-XPathUsage/22010 XPath Usage.xml': 0.978,
    '20000 Variables/22015-Variable-Processing-CustomFunctionSignatures/22015 Custom Function Signatures Processing.xml': 0.078,
    '20000 Variables/22020-Variable-Processing-Parameters/22020 Parameters.xml': 0.526,
    '20000 Variables/22030-Variable-Processing-GeneralVariables/22030 General Variables.xml': 0.262,
    '20000 Variables/22040-Variable-Processing-FactVariables/22040 Fact Variables.xml': 0.613,
    '20000 Variables/22050-Variable-Processing-Filters/22050 Filters.xml': 0.074,
    '20000 Variables/22060-Variable-Processing-VariableNames/22060 Variable Names.xml': 0.295,
    '20000 Variables/22070-Variable-Processing-VariableSetFilterRelationships/22070 Variable Set Filter Relationships.xml': 0.094,
    '20000 Variables/22090-Variable-Processing-VariableSetRelationships/22090 Variable Set Relationship.xml': 0.291,
    '20000 Variables/22140-Variable-Processing-Precondition/22140 Preconditions.xml': 0.236,
    '20000 Variables/22160-Variable-Processing-Evaluation/22160 Evaluation.xml': 0.139,
    '20000 Variables/22170-Variable-Processing-BindAsSequence/22170 Bind As Sequence.xml': 1.909,
    '20000 Variables/22180-Variable-Processing-BindEmpty/22180 Bind To Empty Sequence.xml': 1.486,
    '20000 Variables/23020-Variable-AspectTests-TypedDimension/23020 AspectTests TypedDimension.xml': 0.189,
    '20000 Variables/23030-Variable-AspectTests-DefaultDimension/23030 AspectTests DefaultDimension.xml': 0.028,
    '20000 Variables/23040-VariableStaticAnalysis-prohibitedNamespaceUsedForCustomFunction/23040-VariableStaticAnalysis-prohibitedNamespaceUsedForCustomFunction.xml': 0.018,
    '30000 Assertions/31110-ConsistencyAssertion-StaticAnalysis-radiusConflict/31110 Consistency Assertion Radius Conflict.xml': 0.015,
    '30000 Assertions/31130-ConsistencyAssertion-StaticAnalysis-variablesNotAllowed/31130 Consistency Assertion Variables Not Allowed.xml': 0.030,
    '30000 Assertions/31140-ConsistencyAssertion-StaticAnalysis-missingFormulae/31140 Consistency Assertion Missing Formulae.xml': 0.014,
    '30000 Assertions/31210-ConsistencyAssertion-Processing/31210 Consistency Assertion Processing.xml': 0.784,
    '30000 Assertions/31220-ConsistencyAssertion-Processing-Nil/31220 Consistency Assertion Nil Processing.xml': 0.362,
    '30000 Assertions/31230-ConsistencyAssertion-Processing-Accuracy/31230 Consistency Assertion Processing.xml': 0.666,
    '30000 Assertions/31410-ConsistencyAssertion-UseCases-BasicCalculation/31410 Use Cases Basic Calculation.xml': 0.128,
    '30000 Assertions/31420-ConsistencyAssertion-UseCases-DerivedRiskedCapital/31420 Use Case Derived Risked Capital.xml': 0.048,
    '30000 Assertions/31430-ConsistencyAssertion-UseCases-Pharmaceutical/31430 Use Cases Pharmaceutical.xml': 0.220,
    '30000 Assertions/31440-ConsistencyAssertion-UseCases-DimensionalWeightedAverage/31440 Use Cases Dimensional Weighted Average.xml': 0.086,
    '30000 Assertions/32110-ExistenceAssertion-StaticAnalysis-Element/32110 Existence Assertion Element Static Analysis .xml': 0.013,
    '30000 Assertions/32120-ExistenceAssertion-StaticAnalysis-Relationships/32120 Existence Assertion Relationship Static Analysis.xml': 0.014,
    '30000 Assertions/32210-ExistenceAssertion-Processing/32210 Existence Assertion Processing.xml': 0.115,
    '30000 Assertions/33210-ValueAssertion-Processing/33210 Value Assertion Processing.xml': 0.247,
    '30000 Assertions/34110-MultiAssertion-Processing/34110 Multi Assertion Processing.xml': 0.122,
    '40000 Filters/41210-BooleanFilter-Processing-And/41210 Boolean And Filter Processing.xml': 0.133,
    '40000 Filters/41220-BooleanFilter-Processing-Or/41220 Boolean Or Filter Processing.xml': 0.064,
    '40000 Filters/41221-BooleanFilter-Processing-NoChildren/41221 Boolean Filter Processing No Children.xml': 0.095,
    '40000 Filters/41230-BooleanFilter-Processing-FilterRelationships/41230 Boolean Filter Relationships Processing.xml': 0.050,
    '40000 Filters/42210-ConceptFilter-Processing-ConceptName/42210 ConceptFilter Processing ConceptName.xml': 0.137,
    '40000 Filters/42220-ConceptFilter-Processing-ConceptPeriodType/42220 ConceptFilter Processing ConceptPeriodType.xml': 0.080,
    '40000 Filters/42230-ConceptFilter-Processing-ConceptBalance/42230 ConceptFilter Processing ConceptBalance.xml': 0.134,
    '40000 Filters/42240-ConceptFilter-Processing-ConceptCustomAttribute/42240 ConceptFilter Processing ConceptCustomAttribute.xml': 0.121,
    '40000 Filters/42250-ConceptFilter-Processing-ConceptDataType/42250 ConceptFilter Processing ConceptDataType.xml': 0.139,
    '40000 Filters/42260-ConceptFilter-Processing-ConceptSubstitutionGroup/42260 ConceptFilter Processing ConceptSubstitutionGroup.xml': 0.184,
    '40000 Filters/43130-DimensionFilter-StaticAnalysis-DimensionMember Filter/43130 DimensionMember Filter.xml': 0.229,
    '40000 Filters/43210-DimensionFilter-Processing-ExplicitDimension/43210 Explicit dimension Filter Processing.xml': 0.680,
    '40000 Filters/43230-DimensionFilter-Processing-DomainMember/43230 Dimension Member Filter Processing.xml': 0.524,
    '40000 Filters/43240-DimensionFilter-Processing-TypedDimension/43240 Typed dimension Filter Processing.xml': 0.143,
    '40000 Filters/44210-EntityFilter-Processing-EntityIdentifier/44210 EntityFilter Processing EntityIdentifier.xml': 0.040,
    '40000 Filters/44220-EntityFilter-Processing-SpecificScheme/44220 EntityFilter Processing SpecificScheme.xml': 0.099,
    '40000 Filters/44230-EntityFilter-Processing-RegexpScheme/44230 EntityFilter Processing RegexpScheme.xml': 0.040,
    '40000 Filters/44240-EntityFilter-Processing-SpecificIdentifier/44240 EntityFilter Processing SpecificIdentifier.xml': 0.040,
    '40000 Filters/44250-EntityFilter-Processing-RegexpIdentifier/44250 EntityFilter Processing RegexpIdentifier.xml': 0.055,
    '40000 Filters/45210-GeneralFilter-Processing/45210 General Filter Processing.xml': 0.298,
    '40000 Filters/46210-ImplicitFilter-Processing-NonDimensional/46210 NonDimensional ImplicitFilter Processing.xml': 0.648,
    '40000 Filters/46220-ImplicitFilter-Processing-Dimensional/46220 Dimensional ImplicitFilter Processing.xml': 1.191,
    '40000 Filters/47200-NoMatchingFilter-Processing/47200 No MatchingFilter Processing.xml': 0.047,
    '40000 Filters/47201-ConceptMatchingFilter-Processing/47201 ConceptMatchingFilter Processing.xml': 0.154,
    '40000 Filters/47202-LocationMatchingFilter-Processing/47202 LocationMatchingFilter Processing.xml': 0.047,
    '40000 Filters/47203-UnitMatchingFilter-Processing/47203 UnitMatchingFilter Processing.xml': 0.049,
    '40000 Filters/47204-EntityIdentifierMatchingFilter-Processing/47204 EntityIdentifierMatchingFilter Processing.xml': 0.117,
    '40000 Filters/47205-PeriodMatchingFilter-Processing/47205 PeriodMatchingFilter Processing.xml': 0.047,
    '40000 Filters/47206-CompleteSegmentMatchingFilter-Processing/47206 CompleteSegmentMatchingFilter Processing.xml': 0.371,
    '40000 Filters/47207-NonXDTSegmentMatchingFilter-Processing/47207 NonXDTSegmentMatchingFilter Processing.xml': 0.458,
    '40000 Filters/47209-CompleteScenarioMatchingFilter-Processing/47209 CompleteScenarioMatchingFilter Processing.xml': 0.304,
    '40000 Filters/47210-NonXDTScenarioMatchingFilter-Processing/47210 NonXDTScenarioMatchingFilter Processing.xml': 0.457,
    '40000 Filters/47211-ScenarioDimensionMatchingFilter-Processing/47211 ScenarioDimensionMatchingFilter Processing.xml': 0.574,
    '40000 Filters/47212-DimensionMatchingFilter-Processing/47212 DimensionMatchingFilter Processing.xml': 0.552,
    '40000 Filters/47213-MatchingFilter-MatchVariableInappropriateValues-Processing/47213 MatchingFilter-MatchVariableInappropriateValues Processing.xml': 0.216,
    '40000 Filters/47221-ConceptMatchingFilter-Processing-Sequences/47221 ConceptMatchingFilter Processing Sequences.xml': 0.152,
    '40000 Filters/47222-LocationMatchingFilter-Processing-Sequences/47222 LocationMatchingFilter Processing Sequences.xml': 0.154,
    '40000 Filters/47223-UnitMatchingFilter-Processing-Sequences/47223 UnitMatchingFilter Processing Sequences.xml': 0.154,
    '40000 Filters/47224-EntityIdentifierMatchingFilter-Processing-Sequences/47224 EntityIdentifierMatchingFilter Processing Sequences.xml': 0.221,
    '40000 Filters/47225-PeriodMatchingFilter-Processing-Sequences/47225 PeriodMatchingFilter Processing Sequences.xml': 0.159,
    '40000 Filters/47226-CompleteSegmentMatchingFilter-Processing-Sequences/47226 CompleteSegmentMatchingFilter Processing Sequences.xml': 0.256,
    '40000 Filters/47227-NonXDTSegmentMatchingFilter-Processing-Sequences/47227 NonXDTSegmentMatchingFilter Processing Sequences.xml': 0.254,
    '40000 Filters/47229-CompleteScenarioMatchingFilter-Processing-Sequences/47229 CompleteScenarioMatchingFilter Processing Sequences.xml': 0.256,
    '40000 Filters/47230-NonXDTScenarioMatchingFilter-Processing-Sequences/47230 NonXDTScenarioMatchingFilter Processing Sequences.xml': 0.257,
    '40000 Filters/47231-ScenarioDimensionMatchingFilter-Processing-Sequences/47231 ScenarioDimensionMatchingFilter Processing Sequences.xml': 0.477,
    '40000 Filters/48210-PeriodFilter-Processing-Period/48210 PeriodFilter Processing Period.xml': 0.223,
    '40000 Filters/48220-PeriodFilter-Processing-PeriodStart/48220 PeriodFilter Processing PeriodStart.xml': 0.094,
    '40000 Filters/48230-PeriodFilter-Processing-PeriodEnd/48230 PeriodFilter Processing PeriodEnd.xml': 0.081,
    '40000 Filters/48240-PeriodFilter-Processing-PeriodInstant/48240 PeriodFilter Processing PeriodInstant.xml': 0.097,
    '40000 Filters/48250-PeriodFilter-Processing-Forever/48250 PeriodFilter Processing Forever.xml': 0.040,
    '40000 Filters/48260-PeriodFilter-Processing-InstantDuration/48260 PeriodFilter Processing InstantDuration.xml': 0.100,
    '40000 Filters/49210-RelativeFilter-Processing-Dimensional/49210 Relative Dimensional Filter Processing.xml': 0.240,
    '40000 Filters/49220-RelativeFilter-Processing-NonDimensional/49220 Relative NonDimensional Filter Processing.xml': 0.088,
    '40000 Filters/50210-SegmentScenarioFilter-Processing-Segment/50210 SegmentScenarioFilter Processing Segment.xml': 0.113,
    '40000 Filters/50220-SegmentScenarioFilter-Processing-Scenario/50220 SegmentScenarioFilter Processing Scenario.xml': 0.083,
    '40000 Filters/51210-TupleFilter-Processing-Parent/51210 Tuple Parent Processing.xml': 0.109,
    '40000 Filters/51220-TupleFilter-Processing-Ancestor/51220 Tuple Ancestor Processing.xml': 0.095,
    '40000 Filters/51230-TupleFilter-Processing-Sibling/51230 Tuple Sibling Processing.xml': 0.047,
    '40000 Filters/51240-TupleFilter-Processing-Location/51240 Tuple Location Processing.xml': 0.202,
    '40000 Filters/52210-UnitFilter-Processing-SingleMeasure/52210 Unit Single Measure Processing.xml': 0.124,
    '40000 Filters/52220-UnitFilter-Processing-General/52220 Unit General Measures Processing.xml': 0.161,
    '40000 Filters/53210-ValueFilter-Processing-Nil/53210 ValueFilter Processing Nil.xml': 0.040,
    '40000 Filters/53230-ValueFilter-Processing-Precision/53230 ValueFilter Processing Precision.xml': 0.084,
    '60000 Extensions/60100 GenericMessages-Processing/60100 GenericMessages Processing.xml': 0.153,
    '60000 Extensions/60110 AssertionSeverity-Processing/60110 Assertion Severity Processing.xml': 0.112,
    '60000 Extensions/60200 CustomXPathFuctions-Processing/60200 CustomXPathFunction Processing.xml': 1.085,
    '60000 Extensions/61000 AspectCoverFilter-Processing/61000 AspectCoverFilter Processing.xml': 0.684,
    '60000 Extensions/61100 ConceptRelationsFilter-Processing/61100 ConceptRelationsFilter Processing.xml': 0.496,
}.items()}

config = ConformanceSuiteConfig(
    approximate_relative_timing=TIMING,
    file='formula/tests/index.xml',
    info_url='https://specifications.xbrl.org/release-history-formula-1.0-formula-conf.html',
    local_filepath='formula.zip',
    name=PurePath(__file__).stem,
    network_or_cache_required=False,
    shards=4,
)
